-- Some globals

gravity = 1000
ground_level = 400

-- The Player

local player = {
   x = 400, y = 400, xv = 0, yv = 0,
   width = 32, height = 32,
   jumpsLeft = 2,
   dJump = true
}

function player:draw()
   love.graphics.setColor(255, 0, 0, 255)
   love.graphics.rectangle("fill", self.x, self.y, self.width, self.height)
end

function player:update(dt)
   -- Move player based on velocity and gravity
   self.yv = self.yv + gravity * dt
   self.x = self.x + self.xv * dt
   self.y = self.y + self.yv * dt

   -- move to ground if necesarry
   if self.y + self.height >= ground_level then
      self.mode = 'ground'
      self.yv = 0
      self.y = ground_level - self.height
   end

   -- reset jump count if on ground
   if self.mode == 'ground' then
      if self.dJump then
         self.jumpsLeft = 2
      else
         self.jumpsLeft = 1
      end
   end

   -- switch mode to 'air' if moving down and not on ground.
   if self.mode == 'jump' and self.yv > 0 then
      self.mode = 'air'
   end
end

function player:jump()
   if self.jumpsLeft > 0 and self.mode ~= 'jump' then
      self.jumpsLeft = self.jumpsLeft - 1
      self.mode = 'jump'
      self.yv = -400
   end
end

-- Love Callbacks

function love.update(dt)
   player:update(dt)
end

function love.draw()
   love.graphics.setColor(255, 255, 255)
   love.graphics.printf("Player mode: " .. player.mode, 10, 10, 800, "left")
   love.graphics.setColor(0, 0, 255, 255)
   love.graphics.rectangle("fill", 0, ground_level, love.graphics.getDimensions())
   player:draw()
end

function love.keypressed(key, isrepeat)
   if key == ' ' then
      player:jump()
   end
end
